@@ -22,13 +22,15 @@
 
 import logging
 import math
+import os
 import platform
 import sys
 import time
+import re
 
-from subprocess import run
-from subprocess import PIPE, STDOUT
-from typing import List
+from typing import List, Union
+from enum import Enum
+from typing import Set
 
 from amdsmi_init import *
 from BDF import BDF
@@ -48,6 +50,7 @@ class AMDSMIHelpers():
         self._is_hypervisor = False
         self._is_virtual_os = False
         self._is_baremetal = False
+        self._is_passthrough = False
 
         self._is_linux = False
         self._is_windows = False
@@ -56,11 +59,23 @@ class AMDSMIHelpers():
             self._is_linux = True
             logging.debug(f"AMDSMIHelpers: Platform is linux:{self._is_linux}")
 
-            output = run(["lscpu"], stdout=PIPE, stderr=STDOUT, encoding="UTF-8").stdout
-            if "hypervisor" not in output:
-                self._is_baremetal = True
-            else:
-                self._is_virtual_os = True
+            try:
+                with open('/proc/cpuinfo', 'r') as f:
+                    if 'hypervisor' in f.read():
+                        self._is_virtual_os = True
+            except IOError:
+                pass
+
+            self._is_baremetal = not self._is_virtual_os
+
+            # Check for passthrough system filtering by device id
+            output = self.get_pci_device_ids()
+            passthrough_device_ids = ["7460", "73c8", "74a0", "74a1", "74a2"]
+            if any(('0x' + device_id) in output for device_id in passthrough_device_ids):
+                if self._is_virtual_os:
+                    self._is_baremetal = True
+                    self._is_virtual_os = False
+                    self._is_passthrough = True
 
 
     def os_info(self, string_format=True):
@@ -88,10 +103,14 @@ class AMDSMIHelpers():
         else:
             operating_system_type = "Unknown"
 
+        # Passthrough Override
+        if self._is_passthrough:
+            operating_system_type = "Guest (Passthrough)"
+
         if string_format:
             return f"{operating_system} {operating_system_type}"
-        else:
-            return (operating_system, operating_system_type)
+
+        return (operating_system, operating_system_type)
 
 
     def is_virtual_os(self):
@@ -285,7 +304,21 @@ class AMDSMIHelpers():
         return (gpu_choices, gpu_choices_str)
 
 
-    def get_device_handles_from_gpu_selections(self, gpu_selections: List[str], gpu_choices=None):
+    @staticmethod
+    def is_UUID(uuid_question: str) -> bool:
+        """Determine if given string is of valid UUID format
+        Args:
+            uuid_question (str): the given string to be evaluated.
+        Returns:
+            True or False: wether the UUID given matches the UUID format.
+        """
+        UUID_pattern = re.compile("^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$", flags=re.IGNORECASE)
+        if re.match(UUID_pattern, uuid_question) is None:
+            return False
+        return True
+
+
+    def get_device_handles_from_gpu_selections(self, gpu_selections: List[str], gpu_choices=None) -> tuple:
         """Convert provided gpu_selections to device_handles
 
         Args:
@@ -293,17 +326,18 @@ class AMDSMIHelpers():
                     ex: ID:0  | BDF:0000:23:00.0 | UUID:ffffffff-0000-1000-0000-000000000000
             gpu_choices (dict{gpu_choices}): This is a dictionary of the possible gpu_choices
         Returns:
-            (True, list[device_handles]): Returns a list of all the gpu_selections converted to
+            (True, True, list[device_handles]): Returns a list of all the gpu_selections converted to
                 amdsmi device_handles
-            (False, str): Return False, and the first input that failed to be converted
+            (False, valid_gpu_format, str): Return False, whether the format of the GPU input is valid, and the first input that failed to be converted
         """
         if 'all' in gpu_selections:
-            return (True, amdsmi_interface.amdsmi_get_processor_handles())
+            return True, True, amdsmi_interface.amdsmi_get_processor_handles()
 
         if isinstance(gpu_selections, str):
             gpu_selections = [gpu_selections]
 
         if gpu_choices is None:
+            # obtains dictionary of possible gpu choices
             gpu_choices = self.get_gpu_choices()[0]
 
         selected_device_handles = []
@@ -312,6 +346,7 @@ class AMDSMIHelpers():
 
             for gpu_id, gpu_info in gpu_choices.items():
                 bdf = gpu_info['BDF']
+                is_bdf = True
                 uuid = gpu_info['UUID']
                 device_handle = gpu_info['Device Handle']
 
@@ -327,13 +362,16 @@ class AMDSMIHelpers():
                             valid_gpu_choice = True
                             break
                     except Exception:
-                        # Ignore exception when checking if the gpu_choice is a BDF
+                        is_bdf = False
                         pass
 
             if not valid_gpu_choice:
                 logging.debug(f"AMDSMIHelpers.get_device_handles_from_gpu_selections - Unable to convert {gpu_selection}")
-                return False, gpu_selection
-        return True, selected_device_handles
+                valid_gpu_format = True
+                if not self.is_UUID(gpu_selection) and not gpu_selection.isdigit() and not is_bdf:
+                    valid_gpu_format = False
+                return False, valid_gpu_format, gpu_selection
+        return True, True, selected_device_handles
 
 
     def get_device_handles_from_cpu_selections(self, cpu_selections: List[str], cpu_choices=None):
@@ -349,7 +387,7 @@ class AMDSMIHelpers():
             (False, str): Return False, and the first input that failed to be converted
         """
         if 'all' in cpu_selections:
-            return (True, amdsmi_interface.amdsmi_get_cpusocket_handles())
+            return True, True, amdsmi_interface.amdsmi_get_cpusocket_handles()
 
         if isinstance(cpu_selections, str):
             cpu_selections = [cpu_selections]
@@ -370,8 +408,11 @@ class AMDSMIHelpers():
                     break
             if not valid_cpu_choice:
                 logging.debug(f"AMDSMIHelpers.get_device_handles_from_cpu_selections - Unable to convert {cpu_selection}")
-                return False, cpu_selection
-        return True, selected_device_handles
+                valid_cpu_format = True
+                if not cpu_selection.isdigit():
+                    valid_cpu_format = False
+                return False, valid_cpu_format, cpu_selection
+        return True, True, selected_device_handles
 
 
     def get_device_handles_from_core_selections(self, core_selections: List[str], core_choices=None):
@@ -387,7 +428,7 @@ class AMDSMIHelpers():
             (False, str): Return False, and the first input that failed to be converted
         """
         if 'all' in core_selections:
-            return (True, amdsmi_interface.amdsmi_get_cpucore_handles())
+            return True, True, amdsmi_interface.amdsmi_get_cpucore_handles()
 
         if isinstance(core_selections, str):
             core_selections = [core_selections]
@@ -408,11 +449,14 @@ class AMDSMIHelpers():
                     break
             if not valid_core_choice:
                 logging.debug(f"AMDSMIHelpers.get_device_handles_from_core_selections - Unable to convert {core_selection}")
-                return False, core_selection
-        return True, selected_device_handles
+                valid_core_format = True
+                if not core_selection.isdigit():
+                    valid_core_format = False
+                return False, valid_core_format, core_selection
+        return True, True, selected_device_handles
 
 
-    def handle_gpus(self, args,logger, subcommand):
+    def handle_gpus(self, args, logger, subcommand):
         """This function will run execute the subcommands based on the number
             of gpus passed in via args.
         params:
@@ -708,3 +752,66 @@ class AMDSMIHelpers():
                 return f"{bytes_input:3.1f} {unit}"
             bytes_input /= 1024
         return f"{bytes_input:.1f} YB"
+
+
+    def unit_format(self, logger, value, unit):
+        """This function will format output with unit based on the logger output format
+
+        params:
+            args - argparser args to pass to subcommand
+            logger (AMDSMILogger) - Logger to print out output
+            value - the value to be formatted
+            unit - the unit to be formatted with the value
+        return:
+            str or dict : formatted output
+        """
+        if logger.is_json_format():
+            return {"value": value, "unit": unit}
+        if logger.is_human_readable_format():
+            return f"{value} {unit}".rstrip()
+        return f"{value}"
+
+    class SI_Unit(float, Enum):
+        GIGA = 1000000000  # 10^9
+        MEGA = 1000000     # 10^6
+        KILO = 1000        # 10^3
+        HECTO = 100        # 10^2
+        DEKA = 10          # 10^1
+        BASE = 1           # 10^0
+        DECI = 0.1         # 10^-1
+        CENTI = 0.01       # 10^-2
+        MILLI = 0.001      # 10^-3
+        MICRO = 0.000001   # 10^-6
+        NANO = 0.000000001 # 10^-9
+
+    def convert_SI_unit(self, val: Union[int, float], unit_in: SI_Unit, unit_out = SI_Unit.BASE) -> Union[int, float]:
+        """This function will convert a value into another
+         scientific (SI) unit. Defaults unit_out to SI_Unit.BASE
+
+        params:
+            val: int or float unit to convert
+            unit_in: Requires using SI_Unit to set current value's SI unit (eg. SI_Unit.MICRO)
+            unit_out - Requires using SI_Unit to set current value's SI unit
+             default value is SI_Unit.BASE (eg. SI_Unit.MICRO)
+        return:
+            int or float : converted SI unit of value requested
+        """
+        if isinstance(val, float):
+            return val * unit_in / unit_out
+        elif isinstance(val, int):
+            return int(float(val) * unit_in / unit_out)
+        else:
+            raise TypeError("val must be an int or float")
+
+    def get_pci_device_ids(self) -> Set[str]:
+        pci_devices_path = "/sys/bus/pci/devices"
+        pci_devices: set[str] = set()
+        for device in os.listdir(pci_devices_path):
+            device_path = os.path.join(pci_devices_path, device, "device")
+            try:
+                with open(device_path, 'r') as f:
+                    device = f.read().strip()
+                    pci_devices.add(device)
+            except Exception as _:
+                continue
+        return pci_devices
