@@ -71,146 +71,146 @@
 
 void getFWNameFromId(int id, char *name)
 {
-	switch (id) {
-	case FW_ID_SMU:
-		strcpy(name, "SMU");
-		break;
-	case FW_ID_CP_CE:
-		strcpy(name, "CP_CE");
-		break;
-	case FW_ID_CP_PFP:
-		strcpy(name, "CP_PFP");
-		break;
-	case FW_ID_CP_ME:
-		strcpy(name, "CP_ME");
-		break;
-	case FW_ID_CP_MEC_JT1:
-		strcpy(name, "CP_MEC_JT1");
-		break;
-	case FW_ID_CP_MEC_JT2:
-		strcpy(name, "CP_MEC_JT2");
-		break;
-	case FW_ID_CP_MEC1:
-		strcpy(name, "CP_MEC1");
-		break;
-	case FW_ID_CP_MEC2:
-		strcpy(name, "CP_MEC2");
-		break;
-	case FW_ID_RLC:
-		strcpy(name, "RLC");
-		break;
-	case FW_ID_SDMA0:
-		strcpy(name, "SDMA0");
-		break;
-	case FW_ID_SDMA1:
-		strcpy(name, "SDMA1");
-		break;
-	case FW_ID_SDMA2:
-		strcpy(name, "SDMA2");
-		break;
-	case FW_ID_SDMA3:
-		strcpy(name, "SDMA3");
-		break;
-	case FW_ID_SDMA4:
-		strcpy(name, "SDMA4");
-		break;
-	case FW_ID_SDMA5:
-		strcpy(name, "SDMA5");
-		break;
-	case FW_ID_SDMA6:
-		strcpy(name, "SDMA6");
-		break;
-	case FW_ID_SDMA7:
-		strcpy(name, "SDMA7");
-		break;
-	case FW_ID_VCN:
-		strcpy(name, "VCN");
-		break;
-	case FW_ID_UVD:
-		strcpy(name, "UVD");
-		break;
-	case FW_ID_VCE:
-		strcpy(name, "VCE");
-		break;
-	case FW_ID_ISP:
-		strcpy(name, "ISP");
-		break;
-	case FW_ID_DMCU_ERAM:
-		strcpy(name, "DMCU_ERAM");
-		break;
-	case FW_ID_DMCU_ISR:
-		strcpy(name, "DMCU_ISR");
-		break;
-	case FW_ID_RLC_RESTORE_LIST_GPM_MEM:
-		strcpy(name, "RLC_RESTORE_LIST_GPM_MEM");
-		break;
-	case FW_ID_RLC_RESTORE_LIST_SRM_MEM:
-		strcpy(name, "RLC_RESTORE_LIST_SRM_MEM");
-		break;
-	case FW_ID_RLC_RESTORE_LIST_CNTL:
-		strcpy(name, "RLC_RESTORE_LIST_CNTL");
-		break;
-	case FW_ID_RLC_V:
-		strcpy(name, "RLC_V");
-		break;
-	case FW_ID_MMSCH:
-		strcpy(name, "MMSCH");
-		break;
-	case FW_ID_PSP_SYSDRV:
-		strcpy(name, "PSP_SYSDRV");
-		break;
-	case FW_ID_PSP_SOSDRV:
-		strcpy(name, "PSP_SOSDRV");
-		break;
-	case FW_ID_PSP_TOC:
-		strcpy(name, "PSP_TOC");
-		break;
-	case FW_ID_PSP_KEYDB:
-		strcpy(name, "PSP_KEYDB");
-		break;
-	case FW_ID_DFC:
-		strcpy(name, "DFC");
-		break;
-	case FW_ID_PSP_SPL:
-		strcpy(name, "PSP_SPL");
-		break;
-	case FW_ID_DRV_CAP:
-		strcpy(name, "DRV_CAP");
-		break;
-	case FW_ID_MC:
-		strcpy(name, "MC");
-		break;
-	case FW_ID_PSP_BL:
-		strcpy(name, "PSP_BL");
-		break;
-	case FW_ID_CP_PM4:
-		strcpy(name, "CP_PM4");
-		break;
-	case FW_ID_ASD:
-		strcpy(name, "ID_ASD");
-		break;
-	case FW_ID_TA_RAS:
-		strcpy(name, "ID_TA_RAS");
-		break;
-	case FW_ID_TA_XGMI:
-		strcpy(name, "ID_TA_XGMI");
-		break;
-	case FW_ID_RLC_SRLG:
-		strcpy(name, "ID_RLC_SRLG");
-		break;
-	case FW_ID_RLC_SRLS:
-		strcpy(name, "ID_RLC_SRLS");
-		break;
-	case FW_ID_PM:
-		strcpy(name, "ID_PM");
-		break;
-	case FW_ID_DMCU:
-		strcpy(name, "ID_DMCU");
-		break;
-	default:
-		strcpy(name, "");
-		break;
-	}
+    switch (id) {
+    case AMDSMI_FW_ID_SMU:
+        strcpy(name, "SMU");
+        break;
+    case AMDSMI_FW_ID_CP_CE:
+        strcpy(name, "CP_CE");
+        break;
+    case AMDSMI_FW_ID_CP_PFP:
+        strcpy(name, "CP_PFP");
+        break;
+    case AMDSMI_FW_ID_CP_ME:
+        strcpy(name, "CP_ME");
+        break;
+    case AMDSMI_FW_ID_CP_MEC_JT1:
+        strcpy(name, "CP_MEC_JT1");
+        break;
+    case AMDSMI_FW_ID_CP_MEC_JT2:
+        strcpy(name, "CP_MEC_JT2");
+        break;
+    case AMDSMI_FW_ID_CP_MEC1:
+        strcpy(name, "CP_MEC1");
+        break;
+    case AMDSMI_FW_ID_CP_MEC2:
+        strcpy(name, "CP_MEC2");
+        break;
+    case AMDSMI_FW_ID_RLC:
+        strcpy(name, "RLC");
+        break;
+    case AMDSMI_FW_ID_SDMA0:
+        strcpy(name, "SDMA0");
+        break;
+    case AMDSMI_FW_ID_SDMA1:
+        strcpy(name, "SDMA1");
+        break;
+    case AMDSMI_FW_ID_SDMA2:
+        strcpy(name, "SDMA2");
+        break;
+    case AMDSMI_FW_ID_SDMA3:
+        strcpy(name, "SDMA3");
+        break;
+    case AMDSMI_FW_ID_SDMA4:
+        strcpy(name, "SDMA4");
+        break;
+    case AMDSMI_FW_ID_SDMA5:
+        strcpy(name, "SDMA5");
+        break;
+    case AMDSMI_FW_ID_SDMA6:
+        strcpy(name, "SDMA6");
+        break;
+    case AMDSMI_FW_ID_SDMA7:
+        strcpy(name, "SDMA7");
+        break;
+    case AMDSMI_FW_ID_VCN:
+        strcpy(name, "VCN");
+        break;
+    case AMDSMI_FW_ID_UVD:
+        strcpy(name, "UVD");
+        break;
+    case AMDSMI_FW_ID_VCE:
+        strcpy(name, "VCE");
+        break;
+    case AMDSMI_FW_ID_ISP:
+        strcpy(name, "ISP");
+        break;
+    case AMDSMI_FW_ID_DMCU_ERAM:
+        strcpy(name, "DMCU_ERAM");
+        break;
+    case AMDSMI_FW_ID_DMCU_ISR:
+        strcpy(name, "DMCU_ISR");
+        break;
+    case AMDSMI_FW_ID_RLC_RESTORE_LIST_GPM_MEM:
+        strcpy(name, "RLC_RESTORE_LIST_GPM_MEM");
+        break;
+    case AMDSMI_FW_ID_RLC_RESTORE_LIST_SRM_MEM:
+        strcpy(name, "RLC_RESTORE_LIST_SRM_MEM");
+        break;
+    case AMDSMI_FW_ID_RLC_RESTORE_LIST_CNTL:
+        strcpy(name, "RLC_RESTORE_LIST_CNTL");
+        break;
+    case AMDSMI_FW_ID_RLC_V:
+        strcpy(name, "RLC_V");
+        break;
+    case AMDSMI_FW_ID_MMSCH:
+        strcpy(name, "MMSCH");
+        break;
+    case AMDSMI_FW_ID_PSP_SYSDRV:
+        strcpy(name, "PSP_SYSDRV");
+        break;
+    case AMDSMI_FW_ID_PSP_SOSDRV:
+        strcpy(name, "PSP_SOSDRV");
+        break;
+    case AMDSMI_FW_ID_PSP_TOC:
+        strcpy(name, "PSP_TOC");
+        break;
+    case AMDSMI_FW_ID_PSP_KEYDB:
+        strcpy(name, "PSP_KEYDB");
+        break;
+    case AMDSMI_FW_ID_DFC:
+        strcpy(name, "DFC");
+        break;
+    case AMDSMI_FW_ID_PSP_SPL:
+        strcpy(name, "PSP_SPL");
+        break;
+    case AMDSMI_FW_ID_DRV_CAP:
+        strcpy(name, "DRV_CAP");
+        break;
+    case AMDSMI_FW_ID_MC:
+        strcpy(name, "MC");
+        break;
+    case AMDSMI_FW_ID_PSP_BL:
+        strcpy(name, "PSP_BL");
+        break;
+    case AMDSMI_FW_ID_CP_PM4:
+        strcpy(name, "CP_PM4");
+        break;
+    case AMDSMI_FW_ID_ASD:
+        strcpy(name, "ID_ASD");
+        break;
+    case AMDSMI_FW_ID_TA_RAS:
+        strcpy(name, "ID_TA_RAS");
+        break;
+    case AMDSMI_FW_ID_TA_XGMI:
+        strcpy(name, "ID_TA_XGMI");
+        break;
+    case AMDSMI_FW_ID_RLC_SRLG:
+        strcpy(name, "ID_RLC_SRLG");
+        break;
+    case AMDSMI_FW_ID_RLC_SRLS:
+        strcpy(name, "ID_RLC_SRLS");
+        break;
+    case AMDSMI_FW_ID_PM:
+        strcpy(name, "ID_PM");
+        break;
+    case AMDSMI_FW_ID_DMCU:
+        strcpy(name, "ID_DMCU");
+        break;
+    default:
+        strcpy(name, "");
+        break;
+    }
 }
 
 template <typename T>
@@ -267,12 +267,12 @@ int main() {
         // For each device of the socket, get name and temperature.
         for (uint32_t j = 0; j < device_count; j++) {
             // Get device type. Since the amdsmi is initialized with
-            // AMD_SMI_INIT_AMD_GPUS, the processor_type must be AMD_GPU.
+            // AMD_SMI_INIT_AMD_GPUS, the processor_type must be AMDSMI_PROCESSOR_TYPE_AMD_GPU.
             processor_type_t processor_type = {};
             ret = amdsmi_get_processor_type(processor_handles[j], &processor_type);
             CHK_AMDSMI_RET(ret)
-            if (processor_type != AMD_GPU) {
-                std::cout << "Expect AMD_GPU device type!\n";
+            if (processor_type != AMDSMI_PROCESSOR_TYPE_AMD_GPU) {
+                std::cout << "Expect AMDSMI_PROCESSOR_TYPE_AMD_GPU device type!\n";
                 return AMDSMI_STATUS_NOT_SUPPORTED;
             }
 
@@ -282,10 +282,10 @@ int main() {
             CHK_AMDSMI_RET(ret)
             printf("    Output of amdsmi_get_gpu_device_bdf:\n");
             printf("\tDevice[%d] BDF %04lx:%02x:%02x.%d\n\n", i,
-                   bdf.fields.domain_number,
-                   bdf.fields.bus_number,
-                   bdf.fields.device_number,
-                   bdf.fields.function_number);
+                   bdf.domain_number,
+                   bdf.bus_number,
+                   bdf.device_number,
+                   bdf.function_number);
 
             // Get handle from BDF
             amdsmi_processor_handle dev_handle;
@@ -383,20 +383,20 @@ int main() {
 
             // Get GFX clock measurements
             amdsmi_clk_info_t gfx_clk_values = {};
-            ret = amdsmi_get_clock_info(processor_handles[j], CLK_TYPE_GFX,
+            ret = amdsmi_get_clock_info(processor_handles[j], AMDSMI_CLK_TYPE_GFX,
                                            &gfx_clk_values);
             CHK_AMDSMI_RET(ret)
             printf("    Output of amdsmi_get_clock_info:\n");
             printf("\tGPU GFX Max Clock: %d\n", gfx_clk_values.max_clk);
-            printf("\tGPU GFX Current Clock: %d\n", gfx_clk_values.cur_clk);
+            printf("\tGPU GFX Current Clock: %d\n", gfx_clk_values.clk);
 
             // Get MEM clock measurements
             amdsmi_clk_info_t mem_clk_values = {};
-            ret = amdsmi_get_clock_info(processor_handles[j], CLK_TYPE_MEM,
+            ret = amdsmi_get_clock_info(processor_handles[j], AMDSMI_CLK_TYPE_MEM,
                                            &mem_clk_values);
             CHK_AMDSMI_RET(ret)
             printf("\tGPU MEM Max Clock: %d\n", mem_clk_values.max_clk);
-            printf("\tGPU MEM Current Clock: %d\n\n", mem_clk_values.cur_clk);
+            printf("\tGPU MEM Current Clock: %d\n\n", mem_clk_values.clk);
 
             // Get PCIe status
             amdsmi_pcie_info_t pcie_info = {};
@@ -411,10 +411,18 @@ int main() {
             printf("\tPCIe max lanes: %d\n", pcie_info.pcie_static.max_pcie_width);
             printf("\tPCIe max speed: %d\n", pcie_info.pcie_static.max_pcie_speed);
 
+            // additional pcie related metrics
+            printf("\tPCIe bandwidth: %d\n", pcie_info.pcie_metric.pcie_bandwidth);
+            printf("\tPCIe replay count: %d\n", pcie_info.pcie_metric.pcie_replay_count);
+            printf("\tPCIe L0 recovery count: %d\n", pcie_info.pcie_metric.pcie_l0_to_recovery_count);
+            printf("\tPCIe rollover count: %d\n", pcie_info.pcie_metric.pcie_replay_roll_over_count);
+            printf("\tPCIe nak received count: %d\n", pcie_info.pcie_metric.pcie_nak_received_count);
+            printf("\tPCIe nak sent count: %d\n", pcie_info.pcie_metric.pcie_nak_sent_count);
+
             // Get VRAM temperature limit
             int64_t temperature = 0;
             ret = amdsmi_get_temp_metric(
-                processor_handles[j], TEMPERATURE_TYPE_VRAM,
+                processor_handles[j], AMDSMI_TEMPERATURE_TYPE_VRAM,
                 AMDSMI_TEMP_CRITICAL, &temperature);
             CHK_AMDSMI_RET(ret)
             printf("    Output of amdsmi_get_temp_metric:\n");
@@ -422,34 +430,38 @@ int main() {
 
             // Get GFX temperature limit
             ret = amdsmi_get_temp_metric(
-                processor_handles[j], TEMPERATURE_TYPE_EDGE,
+                processor_handles[j], AMDSMI_TEMPERATURE_TYPE_EDGE,
                 AMDSMI_TEMP_CRITICAL, &temperature);
-            CHK_AMDSMI_RET(ret)
+            if (ret != amdsmi_status_t::AMDSMI_STATUS_NOT_SUPPORTED) {
+                CHK_AMDSMI_RET(ret)
+            }
             printf("\tGPU GFX temp limit: %ld\n\n", temperature);
 
             // Get temperature measurements
             // amdsmi_temperature_t edge_temp, hotspot_temp, vram_temp,
             // plx_temp;
-            int64_t temp_measurements[TEMPERATURE_TYPE__MAX + 1];
+            int64_t temp_measurements[AMDSMI_TEMPERATURE_TYPE__MAX + 1];
             amdsmi_temperature_type_t temp_types[4] = {
-                TEMPERATURE_TYPE_EDGE, TEMPERATURE_TYPE_HOTSPOT,
-                TEMPERATURE_TYPE_VRAM, TEMPERATURE_TYPE_PLX};
+                AMDSMI_TEMPERATURE_TYPE_EDGE, AMDSMI_TEMPERATURE_TYPE_HOTSPOT,
+                AMDSMI_TEMPERATURE_TYPE_VRAM, AMDSMI_TEMPERATURE_TYPE_PLX};
             for (const auto &temp_type : temp_types) {
                 ret = amdsmi_get_temp_metric(
                     processor_handles[j], temp_type,
                     AMDSMI_TEMP_CURRENT,
                     &temp_measurements[(int)(temp_type)]);
-                CHK_AMDSMI_RET(ret)
+                if (ret != amdsmi_status_t::AMDSMI_STATUS_NOT_SUPPORTED) {
+                    CHK_AMDSMI_RET(ret)
+                }
             }
             printf("    Output of amdsmi_get_temp_metric:\n");
             printf("\tGPU Edge temp measurement: %ld\n",
-                   temp_measurements[TEMPERATURE_TYPE_EDGE]);
+                   temp_measurements[AMDSMI_TEMPERATURE_TYPE_EDGE]);
             printf("\tGPU Hotspot temp measurement: %ld\n",
-                   temp_measurements[TEMPERATURE_TYPE_HOTSPOT]);
+                   temp_measurements[AMDSMI_TEMPERATURE_TYPE_HOTSPOT]);
             printf("\tGPU VRAM temp measurement: %ld\n",
-                   temp_measurements[TEMPERATURE_TYPE_VRAM]);
+                   temp_measurements[AMDSMI_TEMPERATURE_TYPE_VRAM]);
             printf("\tGPU PLX temp measurement: %ld\n\n",
-                   temp_measurements[TEMPERATURE_TYPE_PLX]);
+                   temp_measurements[AMDSMI_TEMPERATURE_TYPE_PLX]);
 
             // Get RAS features enabled
             char block_names[14][10] = {"UMC",   "SDMA",     "GFX", "MMHUB",
@@ -518,42 +530,31 @@ int main() {
             };
 
             uint32_t num_process = 0;
-            ret = amdsmi_get_gpu_process_list(processor_handles[j], &num_process,
-                                          nullptr);
+            ret = amdsmi_get_gpu_process_list(processor_handles[j], &num_process, nullptr);
             CHK_AMDSMI_RET(ret)
             if (!num_process) {
                 printf("No processes found.\n");
             } else {
-                amdsmi_process_handle_t process_list[num_process];
-                amdsmi_proc_info_t info_list[num_process];
+                std::cout << "Processes found: " << num_process << "\n";
+                amdsmi_proc_info_t process_info_list[num_process];
                 amdsmi_proc_info_t process = {};
                 uint64_t mem = 0, gtt_mem = 0, cpu_mem = 0, vram_mem = 0;
                 uint64_t gfx = 0, enc = 0;
                 char bdf_str[20];
                 sprintf(bdf_str, "%04lx:%02x:%02x.%d",
-                        bdf.fields.domain_number,
-                        bdf.fields.bus_number,
-                        bdf.fields.device_number,
-                        bdf.fields.function_number);
+                        bdf.domain_number,
+                        bdf.bus_number,
+                        bdf.device_number,
+                        bdf.function_number);
                 int num = 0;
-                ret = amdsmi_get_gpu_process_list(processor_handles[j], &num_process,
-                                            process_list);
-                CHK_AMDSMI_RET(ret)
-                for (uint32_t it = 0; it < num_process; it += 1) {
-                    if (getpid() == process_list[it]) {
-                        continue;
-                    }
-                    ret = amdsmi_get_gpu_process_info(processor_handles[j],
-                                                  process_list[it], &process);
-                    if (ret != AMDSMI_STATUS_SUCCESS) {
-                        printf("amdsmi_get_gpu_process_info() failed for "
-                               "process_list[%d], returned %d\n",
-                               it, ret);
-                        continue;
-                    }
-                    info_list[num++] = process;
+                ret = amdsmi_get_gpu_process_list(processor_handles[j], &num_process, process_info_list);
+                std::cout << "Allocation size for process list: " << num_process << "\n";
+                CHK_AMDSMI_RET(ret);
+                for (auto idx = uint32_t(0); idx < num_process; ++idx) {
+                    process = static_cast<amdsmi_proc_info_t>(process_info_list[idx]);
+                    printf("\t *Process id: %ld / Name: %s / VRAM: %lld \n", process.pid, process.name, process.memory_usage.vram_mem);
                 }
-                qsort(info_list, num, sizeof(info_list[0]), compare);
+
                 printf("+=======+==================+============+=============="
                        "+=============+=============+=============+============"
                        "==+=========================================+\n");
@@ -567,41 +568,41 @@ int main() {
                 printf("+=======+"
                        "+=============+=============+=============+============"
                        "==+=========================================+\n");
-                for (int it = 0; it < num; it++) {
+                for (int it = 0; it < num_process; it++) {
                     char command[30];
                     struct passwd *pwd = nullptr;
                     struct stat st;
 
-                    sprintf(command, "/proc/%d", info_list[it].pid);
+                    sprintf(command, "/proc/%d", process_info_list[it].pid);
                     if (stat(command, &st))
                         continue;
                     pwd = getpwuid(st.st_uid);
                     if (!pwd)
                         printf("| %5d | %16s | %10d | %s | %7ld KiB | %7ld KiB "
                                "| %7ld KiB | %7ld KiB  | %lu  %lu |\n",
-                               info_list[it].pid, info_list[it].name, st.st_uid,
-                               bdf_str, info_list[it].mem / 1024,
-                               info_list[it].memory_usage.gtt_mem / 1024,
-                               info_list[it].memory_usage.cpu_mem / 1024,
-                               info_list[it].memory_usage.vram_mem / 1024,
-                               info_list[it].engine_usage.gfx,
-                               info_list[it].engine_usage.enc);
+                               process_info_list[it].pid, process_info_list[it].name, st.st_uid,
+                               bdf_str, process_info_list[it].mem / 1024,
+                               process_info_list[it].memory_usage.gtt_mem / 1024,
+                               process_info_list[it].memory_usage.cpu_mem / 1024,
+                               process_info_list[it].memory_usage.vram_mem / 1024,
+                               process_info_list[it].engine_usage.gfx,
+                               process_info_list[it].engine_usage.enc);
                     else
                         printf("| %5d | %16s | %10s | %s | %7ld KiB | %7ld KiB "
                                "| %7ld KiB | %7ld KiB  | %lu  %lu |\n",
-                               info_list[it].pid, info_list[it].name,
-                               pwd->pw_name, bdf_str, info_list[it].mem / 1024,
-                               info_list[it].memory_usage.gtt_mem / 1024,
-                               info_list[it].memory_usage.cpu_mem / 1024,
-                               info_list[it].memory_usage.vram_mem / 1024,
-                               info_list[it].engine_usage.gfx,
-                               info_list[it].engine_usage.enc);
-                    mem += info_list[it].mem / 1024;
-                    gtt_mem += info_list[it].memory_usage.gtt_mem / 1024;
-                    cpu_mem += info_list[it].memory_usage.cpu_mem / 1024;
-                    vram_mem += info_list[it].memory_usage.vram_mem / 1024;
-                    gfx = info_list[it].engine_usage.gfx;
-                    enc = info_list[it].engine_usage.enc;
+                               process_info_list[it].pid, process_info_list[it].name,
+                               pwd->pw_name, bdf_str, process_info_list[it].mem / 1024,
+                               process_info_list[it].memory_usage.gtt_mem / 1024,
+                               process_info_list[it].memory_usage.cpu_mem / 1024,
+                               process_info_list[it].memory_usage.vram_mem / 1024,
+                               process_info_list[it].engine_usage.gfx,
+                               process_info_list[it].engine_usage.enc);
+                    mem += process_info_list[it].mem / 1024;
+                    gtt_mem += process_info_list[it].memory_usage.gtt_mem / 1024;
+                    cpu_mem += process_info_list[it].memory_usage.cpu_mem / 1024;
+                    vram_mem += process_info_list[it].memory_usage.vram_mem / 1024;
+                    gfx = process_info_list[it].engine_usage.gfx;
+                    enc = process_info_list[it].engine_usage.enc;
                     printf(
                         "+-------+------------------+------------+-------------"
                         "-+-------------+-------------+-------------+----------"
@@ -634,9 +635,11 @@ int main() {
 
             // Get temperature
             int64_t val_i64 = 0;
-            ret =  amdsmi_get_temp_metric(processor_handles[j], TEMPERATURE_TYPE_EDGE,
+            ret =  amdsmi_get_temp_metric(processor_handles[j], AMDSMI_TEMPERATURE_TYPE_EDGE,
                                              AMDSMI_TEMP_CURRENT, &val_i64);
-            CHK_AMDSMI_RET(ret)
+            if (ret != amdsmi_status_t::AMDSMI_STATUS_NOT_SUPPORTED) {
+                CHK_AMDSMI_RET(ret)
+            }
             printf("    Output of  amdsmi_get_temp_metric:\n");
             std::cout << "\t\tTemperature: " << val_i64 << "C"
                       << "\n\n";
@@ -654,15 +657,15 @@ int main() {
             CHK_AMDSMI_RET(ret)
             printf("    Output of amdsmi_get_power_cap_info:\n");
             std::cout << "\t\t Power Cap: " << cap_info.power_cap
-                      << "W\n";
+                      << " uW\n";
             std::cout << "\t\t Default Power Cap: " << cap_info.default_power_cap
-                      << "\n\n";
+                      << " uW\n\n";
             std::cout << "\t\t Dpm Cap: " << cap_info.dpm_cap
-                      << "\n\n";
+                      << " MHz\n\n";
             std::cout << "\t\t Min Power Cap: " << cap_info.min_power_cap
-                      << "\n\n";
+                      << " uW\n\n";
             std::cout << "\t\t Max Power Cap: " << cap_info.max_power_cap
-                      << "\n\n";
+                      << " uW\n\n";
 
             /// Get GPU Metrics info
             std::cout << "\n\n";
@@ -671,10 +674,10 @@ int main() {
             CHK_AMDSMI_RET(ret)
             printf("    Output of amdsmi_get_gpu_metrics_info:\n");
             printf("\tDevice[%d] BDF %04lx:%02x:%02x.%d\n\n", i,
-                   bdf.fields.domain_number,
-                   bdf.fields.bus_number,
-                   bdf.fields.device_number,
-                   bdf.fields.function_number);
+                   bdf.domain_number,
+                   bdf.bus_number,
+                   bdf.device_number,
+                   bdf.function_number);
 
             std::cout << "\t**.common_header.format_revision : "
                       << print_unsigned_int(gpu_metrics.common_header.format_revision) << "\n";
