@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "abcimrstv",
+  0: "abcdfiklmoprstv",
   1: "r",
   2: "r",
   3: "r",
@@ -9,8 +9,8 @@ var indexSectionsWithContent =
   6: "r",
   7: "r",
   8: "r",
-  9: "acistv",
-  10: "rt"
+  9: "acdfiorstv",
+  10: "alrst"
 };
 
 var indexSectionNames =
