@@ -22,6 +22,7 @@ THE SOFTWARE.
 
 #include <iostream>
 #include <iomanip>
+#include <fstream>
 #include <unistd.h>
 #include <vector>
 #include <string>
@@ -40,13 +41,8 @@ THE SOFTWARE.
 #include <atomic>
 #include "video_demuxer.h"
 #include "roc_video_dec.h"
-#include "colorspace_kernels.h"
-#include "resize_kernels.h"
+#include "video_post_process.h"
 
-FILE *fpOut = nullptr;
-enum OutputFormatEnum {
-    native = 0, bgr, bgr48, rgb, rgb48, bgra, bgra64, rgba, rgba64
-};
 std::vector<std::string> st_output_format_name = {"native", "bgr", "bgr48", "rgb", "rgb48", "bgra", "bgra64", "rgba", "rgba64"};
 
 void ShowHelpAndExit(const char *option = NULL) {
@@ -55,113 +51,20 @@ void ShowHelpAndExit(const char *option = NULL) {
     << "-o Output File Path - dumps output if requested; optional" << std::endl
     << "-d GPU device ID (0 for the first device, 1 for the second, etc.); optional; default: 0" << std::endl
     << "-of Output Format name - (native, bgr, bgr48, rgb, rgb48, bgra, bgra64, rgba, rgba64; converts native YUV frame to RGB image format; optional; default: 0" << std::endl
+    << "-resize WxH - (where W is resize width and H is resize height) optional; default: no resize " << std::endl
     << "-crop crop rectangle for output (not used when using interopped decoded frame); optional; default: 0" << std::endl;
 
     exit(0);
 }
 
-void DumpRGBImage(std::string outputfileName, void* pdevMem, OutputSurfaceInfo *surf_info, int rgb_image_size) {
-    if (fpOut == nullptr) {
-        fpOut = fopen(outputfileName.c_str(), "wb");
-    }
-    uint8_t *hstPtr = nullptr;
-    hstPtr = new uint8_t [rgb_image_size];
-    hipError_t hip_status = hipSuccess;
-    hip_status = hipMemcpyDtoH((void *)hstPtr, pdevMem, rgb_image_size);
-    if (hip_status != hipSuccess) {
-        std::cout << "ERROR: hipMemcpyDtoH failed! (" << hip_status << ")" << std::endl;
-        delete [] hstPtr;
-        return;
-    }
-    if (fpOut) {
-        fwrite(hstPtr, 1, rgb_image_size, fpOut);
-    }
-
-    if (hstPtr != nullptr) {
-        delete [] hstPtr;
-        hstPtr = nullptr;
-    }
-}
-
-void ColorConvertYUV2RGB(uint8_t *p_src, OutputSurfaceInfo *surf_info, uint8_t *rgb_dev_mem_ptr, OutputFormatEnum e_output_format, hipStream_t hip_stream) {
-    
-    int  rgb_width = (surf_info->output_width + 1) & ~1;    // has to be a multiple of 2 for hip colorconvert kernels
-    // todo:: get color standard from the decoder
-    if (surf_info->surface_format == rocDecVideoSurfaceFormat_YUV444) {
-        if (e_output_format == bgr)
-          YUV444ToColor24<BGR24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgra)
-          YUV444ToColor32<BGRA32>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 4 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb)
-          YUV444ToColor24<RGB24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgba)
-          YUV444ToColor32<RGBA32>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 4 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-    } else if (surf_info->surface_format == rocDecVideoSurfaceFormat_NV12) {
-        if (e_output_format == bgr)
-          Nv12ToColor24<BGR24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgra)
-          Nv12ToColor32<BGRA32>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 4 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb)
-          Nv12ToColor24<RGB24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgba)
-          Nv12ToColor32<RGBA32>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 4 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-    }
-    if (surf_info->surface_format == rocDecVideoSurfaceFormat_YUV444_16Bit) {
-        if (e_output_format == bgr)
-          YUV444P16ToColor24<BGR24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb)
-          YUV444P16ToColor24<RGB24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgr48)
-          YUV444P16ToColor48<BGR48>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 6 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb48)
-          YUV444P16ToColor48<RGB48>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 6 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgra64)
-          YUV444P16ToColor64<BGRA64>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 8 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgba64)
-          YUV444P16ToColor64<RGBA64>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 8 * rgb_width, surf_info->output_width, 
-                                surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-    } else if (surf_info->surface_format == rocDecVideoSurfaceFormat_P016) {
-        if (e_output_format == bgr)
-          P016ToColor24<BGR24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb)
-          P016ToColor24<RGB24>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 3 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgr48)
-          P016ToColor48<BGR48>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 6 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgb48)
-          P016ToColor48<RGB48>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 6 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == bgra64)
-          P016ToColor64<BGRA64>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 8 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-        else if (e_output_format == rgba64)
-          P016ToColor64<RGBA64>(p_src, surf_info->output_pitch, static_cast<uint8_t *>(rgb_dev_mem_ptr), 8 * rgb_width, surf_info->output_width, 
-                              surf_info->output_height, surf_info->output_vstride, 0, hip_stream);
-    }
-}
-
 constexpr int frame_buffers_size = 2;
 std::queue<uint8_t*> frame_queue[frame_buffers_size];
 std::mutex mutex[frame_buffers_size];
 std::condition_variable cv[frame_buffers_size];
 
 void ColorSpaceConversionThread(std::atomic<bool>& continue_processing, bool convert_to_rgb, Dim *p_resize_dim, OutputSurfaceInfo **surf_info, OutputSurfaceInfo **res_surf_info,
-        OutputFormatEnum e_output_format, uint8_t *p_rgb_dev_mem, uint8_t *p_resize_dev_mem, bool dump_output_frames, std::string &output_file_path, RocVideoDecoder &viddec) {
+        OutputFormatEnum e_output_format, uint8_t *p_rgb_dev_mem, uint8_t *p_resize_dev_mem, bool dump_output_frames,
+        std::string &output_file_path, RocVideoDecoder &viddec, VideoPostProcess &post_proc, bool b_generate_md5) {
 
     size_t rgb_image_size, resize_image_size;
     hipError_t hip_status = hipSuccess;
@@ -216,15 +119,8 @@ void ColorSpaceConversionThread(std::atomic<bool>& continue_processing, bool con
         }
 
         if (convert_to_rgb) {
-            int rgb_width;
-            if (p_surf_info->bit_depth == 8) {
-                rgb_width = (p_surf_info->output_width + 1) & ~1; // has to be a multiple of 2 for hip colorconvert kernels
-                rgb_image_size = ((e_output_format == bgr) || (e_output_format == rgb)) ? rgb_width * p_surf_info->output_height * 3 : rgb_width * p_surf_info->output_height * 4;
-            } else {
-                rgb_width = (p_surf_info->output_width + 1) & ~1;
-                rgb_image_size = ((e_output_format == bgr) || (e_output_format == rgb)) ? rgb_width * p_surf_info->output_height * 3 : ((e_output_format == bgr48) || (e_output_format == rgb48)) ? 
-                                                        rgb_width * p_surf_info->output_height * 6 : rgb_width * p_surf_info->output_height * 8;
-            }
+            uint32_t rgb_stride = post_proc.GetRgbStride(e_output_format, p_surf_info);
+            rgb_image_size = p_surf_info->output_height * rgb_stride;
             if (p_rgb_dev_mem == nullptr) {
                 hip_status = hipMalloc(&p_rgb_dev_mem, rgb_image_size);
                 if (hip_status != hipSuccess) {
@@ -232,14 +128,18 @@ void ColorSpaceConversionThread(std::atomic<bool>& continue_processing, bool con
                     return;
                 }
             }
-            ColorConvertYUV2RGB(out_frame, p_surf_info, p_rgb_dev_mem, e_output_format, viddec.GetStream());
+            post_proc.ColorConvertYUV2RGB(out_frame, p_surf_info, p_rgb_dev_mem, e_output_format, viddec.GetStream());
         }
         if (dump_output_frames) {
             if (convert_to_rgb)
-                DumpRGBImage(output_file_path, p_rgb_dev_mem, p_surf_info, rgb_image_size);
+                viddec.SaveFrameToFile(output_file_path, p_rgb_dev_mem, p_surf_info, rgb_image_size);
             else
                 viddec.SaveFrameToFile(output_file_path, out_frame, p_surf_info);
         }
+        if(b_generate_md5 && convert_to_rgb){
+            viddec.UpdateMd5ForDataBuffer(p_rgb_dev_mem, rgb_image_size);
+        }
+        
 
         cv[current_frame_index].notify_one();
         current_frame_index = (current_frame_index + 1) % frame_buffers_size;
@@ -248,7 +148,10 @@ void ColorSpaceConversionThread(std::atomic<bool>& continue_processing, bool con
 
 int main(int argc, char **argv) {
 
-    std::string input_file_path, output_file_path;
+    std::string input_file_path, output_file_path, md5_file_path;
+    std::fstream ref_md5_file;
+    bool b_generate_md5 = false;
+    bool b_md5_check = false;
     bool dump_output_frames = false;
     bool convert_to_rgb = false;
     int device_id = 0;
@@ -265,6 +168,7 @@ int main(int argc, char **argv) {
     int rgb_width;
     uint8_t* frame_buffers[frame_buffers_size] = {0};
     int current_frame_index = 0;
+    
 
     // Parse command-line arguments
     if(argc <= 1) {
@@ -328,6 +232,22 @@ int main(int argc, char **argv) {
             e_output_format = (OutputFormatEnum)(it - st_output_format_name.begin());
             continue;
         }
+        if (!strcmp(argv[i], "-md5")) {
+            if (i == argc) {
+                ShowHelpAndExit("-md5");
+            }
+            b_generate_md5 = true;
+            continue;
+        }
+        if (!strcmp(argv[i], "-md5_check")) {
+            if (++i == argc) {
+                ShowHelpAndExit("-md5_check");
+            }
+            b_generate_md5 = true;
+            b_md5_check = true;
+            md5_file_path = argv[i];
+            continue;
+        }
         ShowHelpAndExit(argv[i]);
     }
 
@@ -335,6 +255,7 @@ int main(int argc, char **argv) {
         VideoDemuxer demuxer(input_file_path.c_str());
         rocDecVideoCodec rocdec_codec_id = AVCodec2RocDecVideoCodec(demuxer.GetCodecID());
         RocVideoDecoder viddec(device_id, mem_type, rocdec_codec_id, false, p_crop_rect);
+        VideoPostProcess post_process;
 
         std::string device_name, gcn_arch_name;
         int pci_bus_id, pci_domain_id, pci_device_id;
@@ -346,6 +267,13 @@ int main(int argc, char **argv) {
         std::right << std::hex << pci_domain_id << "." << pci_device_id << std::dec << std::endl;
         std::cout << "info: decoding started, please wait!" << std::endl;
 
+        if (b_generate_md5) {
+            viddec.InitMd5();
+        }
+        if (b_md5_check) {
+            ref_md5_file.open(md5_file_path.c_str(), std::ios::in);            
+        }
+
         int n_video_bytes = 0, n_frames_returned = 0, n_frame = 0;
         uint8_t *p_video = nullptr;
         uint8_t *p_frame = nullptr;
@@ -357,7 +285,7 @@ int main(int argc, char **argv) {
         convert_to_rgb = e_output_format != native;
         std::atomic<bool> continue_processing(true);
         std::thread color_space_conversion_thread(ColorSpaceConversionThread, std::ref(continue_processing), std::ref(convert_to_rgb), &resize_dim, &surf_info, &resize_surf_info, std::ref(e_output_format),
-                                    std::ref(p_rgb_dev_mem), std::ref(p_resize_dev_mem), std::ref(dump_output_frames), std::ref(output_file_path), std::ref(viddec));
+                                    std::ref(p_rgb_dev_mem), std::ref(p_resize_dev_mem), std::ref(dump_output_frames), std::ref(output_file_path), std::ref(viddec), std::ref(post_process), b_generate_md5);
 
         auto startTime = std::chrono::high_resolution_clock::now();
         do {
@@ -419,10 +347,6 @@ int main(int argc, char **argv) {
                 return -1;
             }
         }
-        if (fpOut) {
-          fclose(fpOut);
-          fpOut = nullptr;
-        }
         for (int i = 0; i < frame_buffers_size; i++) {
             hip_status = hipFree(frame_buffers[i]);
             if (hip_status != hipSuccess) {
@@ -442,6 +366,39 @@ int main(int argc, char **argv) {
         if (resize_surf_info != nullptr) {
             delete resize_surf_info;
         }
+        if (b_generate_md5) {
+            uint8_t *digest;
+            viddec.FinalizeMd5(&digest);
+            std::cout << "MD5 message digest: ";
+            for (int i = 0; i < 16; i++) {
+                std::cout << std::setfill('0') << std::setw(2) << std::hex << static_cast<int>(digest[i]);
+            }
+            std::cout << std::endl;
+
+            if (b_md5_check) {
+                char ref_md5_string[33], c2[2];
+                uint8_t ref_md5[16];
+                std::string str;
+
+                for (int i = 0; i < 16; i++) {
+                    int c;
+                    ref_md5_file.get(c2[0]);
+                    ref_md5_file.get(c2[1]);
+                    str = c2;
+                    c = std::stoi(str, nullptr, 16);
+                    ref_md5[i] = c;
+                }
+                if (memcmp(digest, ref_md5, 16) == 0) {
+                    std::cout << "MD5 digest matches the reference MD5 digest: " << std::endl;
+                } else {
+                    std::cout << "MD5 digest does not match the reference MD5 digest: " << std::endl;
+                }
+                ref_md5_file.seekg(0, std::ios_base::beg);
+                ref_md5_file.getline(ref_md5_string, 33);
+                std::cout << ref_md5_string << std::endl;
+                ref_md5_file.close();
+            }
+        }
     } catch (const std::exception &ex) {
         std::cout << ex.what() << std::endl;
         exit(1);
