@@ -50,7 +50,8 @@ extern "C" {
  * \brief AMD The rocDecode video decoder for AMD’s GPUs.
  */
 
-#define MAX_FRAME_NUM     16
+#define MAX_FRAME_NUM       16
+
 typedef int (ROCDECAPI *PFNRECONFIGUEFLUSHCALLBACK)(void *, uint32_t, void *);
 
 typedef enum SeiAvcHevcPayloadType_enum {
@@ -177,7 +178,7 @@ class RocVideoDecoder {
        * @param force_zero_latency 
        */
         RocVideoDecoder(int device_id,  OutputSurfaceMemoryType out_mem_type, rocDecVideoCodec codec, bool force_zero_latency = false,
-                          const Rect *p_crop_rect = nullptr, bool extract_user_SEI_Message = false, int max_width = 0, int max_height = 0,
+                          const Rect *p_crop_rect = nullptr, bool extract_user_SEI_Message = false, uint32_t disp_delay = 0, int max_width = 0, int max_height = 0,
                           uint32_t clk_rate = 1000);
         ~RocVideoDecoder();
         
@@ -319,8 +320,9 @@ class RocVideoDecoder {
          * @param output_file_name  - Output file name
          * @param dev_mem           - pointer to surface memory
          * @param surf_info         - surface info
+         * @param rgb_image_size    - image size for rgb (optional). A non_zero value indicates the surf_mem holds an rgb interleaved image and the entire size will be dumped to file
          */
-        void SaveFrameToFile(std::string output_file_name, void *surf_mem, OutputSurfaceInfo *surf_info);
+        void SaveFrameToFile(std::string output_file_name, void *surf_mem, OutputSurfaceInfo *surf_info, size_t rgb_image_size = 0);
 
         /**
          * @brief Helper funtion to close a existing file and dump to new file in case of multiple files using same decoder
@@ -332,6 +334,8 @@ class RocVideoDecoder {
          */
         void InitMd5();
 
+        void UpdateMd5ForDataBuffer(void *pDevMem, int rgb_image_size);
+
         /**
          * @brief Helper function to dump decoded output surface to file
          *
@@ -423,6 +427,7 @@ class RocVideoDecoder {
         OutputSurfaceMemoryType out_mem_type_ = OUT_SURFACE_MEM_DEV_INTERNAL;
         bool b_extract_sei_message_ = false;
         bool b_force_zero_latency_ = false;
+        uint32_t disp_delay_;
         ReconfigParams *p_reconfig_params_ = nullptr;
         int32_t num_frames_flushed_during_reconfig_ = 0;
         hipDeviceProp_t hip_dev_prop_;
